﻿using System;

namespace ELTE.TravelAgency.Data
{
    /// <summary>
    /// Jellemző típusa.
    /// </summary>
    public class FeatureDTO
    {
        /// <summary>
        /// Jellemző azonosítója.
        /// </summary>
        public Int32 Id { get; set; }

        /// <summary>
        /// Jellemző elérhetősége.
        /// </summary>
        public Boolean IsAvailable { get; set; }

        /// <summary>
        /// Jellemzők átalakítása.
        /// </summary>
        /// <param name="features">A jellemzőket reprezentáló szám.</param>
        /// <returns>A jellemzők tömbje.</returns>
        public static FeatureDTO[] Convert(Int32? features)
        {
            FeatureDTO[] result = new FeatureDTO[5];

            if (features == null)
                return result;

            for (Int32 featureIndex = 0; featureIndex < result.Length; featureIndex++)
            {
                result[featureIndex] = new FeatureDTO
                {
                    Id = featureIndex,
                    IsAvailable = ((System.Convert.ToInt32(features.Value) >> featureIndex) % 2 == 1)
                };
            }

            return result;
        }

        /// <summary>
        /// Jellemzők átalakítása.
        /// </summary>
        /// <param name="features">A jellemzőket tömbje.</param>
        /// <returns>A jellemzőket reprezentáló szám.</returns>
        public static Int32? Convert(FeatureDTO[] features)
        {
            if (features == null || features.Length == 0)
                return null;

            Int32 result = 0;

            for (Int32 featureIndex = 0; featureIndex < features.Length; featureIndex++)
            {
                if (features[featureIndex].IsAvailable)
                {
                    result += (1 << features[featureIndex].Id);
                }
            }

            return result;
        }
    }
}
